#
# spec file for package python-persistent
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-persistent
Version:        4.2.4.2
Release:        lp151.2.6
Summary:        Translucent persistent objects
License:        ZPL-2.1
Group:          Development/Languages/Python
Url:            https://github.com/zopefoundation/persistent
Source:         https://files.pythonhosted.org/packages/source/p/persistent/persistent-%{version}.tar.gz
# Documentation requirements:
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module repoze.sphinx.autointerface}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.interface
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
This package contains a generic persistence implementation for Python. It forms
the core protocol for making objects interact "transparently" with a database
such as the ZODB.

%package        devel
Summary:        Translucent persistent objects
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description    devel
This package contains the files needed for binding the %{name} C module.

%package        doc
Summary:        Translucent persistent objects
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description    doc
This package contains documentation files for %{name}.

%prep
%setup -q -n persistent-%{version}
rm -rf persistent.egg-info

%build
%python_build
%{_python_use_flavor python3}
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
%python_install
# don't bother with development files
%{python_expand rm %{buildroot}%{$python_sitearch}/persistent/*.c
  %fdupes -s %{buildroot}%{$python_sitearch}
}

%check
%python_exec setup.py -q test

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.rst COPYRIGHT.txt LICENSE.txt README.rst
%exclude %{python_sitearch}/persistent/*.h
%{python_sitearch}/*

%files %{python_files devel}
%defattr(-,root,root,-)
%dir %{python_sysconfig_path include}/persistent
%{python_sysconfig_path include}/persistent/*.h
%{python_sitearch}/persistent/*.h

%files %{python_files doc}
%defattr(-,root,root,-)
%doc build/sphinx/html/

%changelog
* Sat Jun 24 2017 aloisio@gmx.com
- Update to 4.2.4.2
  * Packaging-only release: fix Python 2.7 manylinux wheels.
  4.2.4.1:
  * Packaging-only release: get manylinux wheel built
    automatically.
  4.2.4:
  * Avoid raising a SystemError: error return without exception
    set when loading an object with slots whose jar generates an
    exception (such as a ZODB POSKeyError) in setstate.
  4.2.3:
  * Fix the hashcode of Python TimeStamp objects on 64-bit
    Python on Windows. See
    https://github.com/zopefoundation/persistent/pull/55
  * Stop calling gc.collect every time PickleCache.incrgc is
    called (every transaction boundary) in pure-Python mode (PyPy).
    This means that the reported size of the cache may be wrong
    (until the next GC), but it is much faster. This should not
    have any observable effects for user code.
  * Stop clearing the dict and slots of objects added to
    PickleCache.new_ghost (typically these values are passed to
    __new__ from the pickle data) in pure-Python mode (PyPy). This
    matches the behaviour of the C code.
  * Add support for Python 3.6.
  * Fix __setstate__ interning when state parameter is not a
    built-in dict
  4.2.2:
  * Drop use of ctypes for determining maximum integer size, to
    increase pure-Python compatibility. See
    https://github.com/zopefoundation/persistent/pull/31
  * Ensure that __slots__ attributes are cleared when a
    persistent object is ghostified. (This excluses classes that
    override __new__. See
    https://github.com/zopefoundation/persistent/wiki/Notes_on_state_
    new_and_slots if you’re curious.)
  4.2.1:
  * Fix the hashcode of C TimeStamp objects on 64-bit Python 3
    on Windows.
  4.2.0:
  * Fixed the Python(/PYPY) implementation TimeStamp.timeTime
    method to have subsecond precision.
  * When testing PURE_PYTHON environments under tox, avoid
    poisoning the user’s global wheel cache.
  * Add support for Python 3.5.
  * Drop support for Python 2.6 and 3.2.
  4.1.1:
  * Fix manifest and re-upload to fix stray files included in
    4.1.0.
  4.1.0:
  * Make the Python implementation of Persistent and PickleCache
    behave more similarly to the C implementation. In particular,
    the Python version can now run the complete ZODB and ZEO test
    suites.
  * Fix the hashcode of the Python TimeStamp on 32-bit platforms.
- Converted to single-spec
- Dropped fix_32-bit_timestamp_hashcode.patch (fixed upstream)
* Sun May 10 2015 benoit.monin@gmx.fr
- update to version 4.0.9:
  * Make the C and Python TimeStamp objects behave more alike
  * Intern keys of object state in __setstate__ to reduce memory
    usage when unpickling multiple objects with the same attributes
  * Add support for PyPy3
  * 100%% branch coverage
- additional changes from version 4.0.8:
  * Add support for Python 3.4
  * In pure-Python Persistent, avoid loading state in _p_activate
    for non-ghost objects (which could corrupt their state). (PR #9)
  * In pure-Python, and don’t throw POSKeyError if _p_activate is
    called on an object that has never been committed. (PR #9)
  * In pure-Python Persistent, avoid calling a subclass’s
    __setattr__ at instance creation time. (PR #8)
  * Make it possible to delete _p_jar / _p_oid of a pure-Python
    Persistent object which has been removed from the jar’s cache
    (fixes aborting a ZODB Connection that has added objects).
    (PR #7)
- additional changes from version 4.0.7:
  * Avoid a KeyError from _p_accessed() on newly-created objects
    under pure-Python: these objects may be assigned to a jar, but
    not yet added to its cache. (PR #6)
  * Avoid a failure in Persistent.__setstate__ when the state dict
    contains exactly two keys. (PR #5)
  * Fix a hang in picklecache invalidation if OIDs are manually
    passed out-of-order. (PR #4)
  * Add PURE_PYTHON environment variable support: if set, the C
    extensions will not be built, imported, or tested
- update project URL
- point the source URL to pypi
- drop type-mismatch.patch: fixed upstream
- add fix_32-bit_timestamp_hashcode.patch: fix timestamp hash
  computation on 32 bit platform
- pass -q to test to avoid spamming the build log
- rename CHANGES.txt and README.txt to CHANGES.rst and README.rst:
  changed upstream
* Fri Mar 21 2014 schwab@linux-m68k.org
- type-mismatch.patch: Use Py_ssize_t rather than PY_LONG_LONG for sizes
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.6: initial build
